==> ejc-skeleton-3.0.0-20250307.083745-350-sources.jar: com/ejianc/framework/skeleton/commonQuery/controller/CommonQueryController.java <==
package com.ejianc.framework.skeleton.commonQuery.controller;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSONArray;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.commonQuery.service.ICommonQueryService;
import com.ejianc.framework.skeleton.fields.service.ICommenQueryFieldsService;
import com.ejianc.framework.skeleton.util.DataTransferEncrypt;

/**
 * @author CJ
 * @Description:
 * @date 2020/7/29 17:21
 */
@RestController
@RequestMapping(value = "/commonQuery/")
public class CommonQueryController {

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private ICommenQueryFieldsService commenQueryFieldsService;
    @Autowired
    private ICommonQueryService commonQueryService;

    @Value("${extend.field.mode:false}")
    private Boolean extFieldsMode;
    
    @Value("${http.valid.mode:false}")
    private Boolean httpValidMode;

    @PostMapping(value = "queryBillInfoByProperty")
    @ResponseBody
    public CommonResponse<JSONArray> queryBillInfoByProperty(HttpServletRequest request,@RequestBody Map<String, String> queryMap) {
    	if(httpValidMode) {
    		Boolean isValid = DataTransferEncrypt.validKey();
        	if(!isValid) {
        		logger.error("您没有请求该接口的权限!");
                return CommonResponse.error("您没有请求该接口的权限!");
        	}
    	}
        if(StringUtils.isBlank(queryMap.get("databaseName"))) {
            logger.error("业务数据库名不能为空！");
            return CommonResponse.error("业务数据库名称不能为空");
        }
        if(StringUtils.isBlank(queryMap.get("tableName"))) {
            logger.error("业务表名不能为空！");
            return CommonResponse.error("业务表名称不能为空");
        }
        if(StringUtils.isBlank(queryMap.get("columns"))) {
            logger.error("查询字段不能为空！");
            return CommonResponse.error("查询字段不能为空");
        }
        if(StringUtils.isBlank(queryMap.get("parameter"))) {
            logger.error("查询条件不能为空！");
            return CommonResponse.error("查询条件不能为空");
        }
        JSONArray result = commenQueryFieldsService.queryBillInfoByProperty(queryMap.get("databaseName"), queryMap.get("tableName"), queryMap.get("columns"), queryMap.get("parameter"));

        return CommonResponse.success("查询成功！", result);
    }

    /** 查询当前工程是否开启扩展字段 */
    @PostMapping(value = "extFieldsModeOpen")
    @ResponseBody
    public CommonResponse<Boolean> extFieldsModeOpen(@RequestBody Map<String, String> queryMap) {
    	if(httpValidMode) {
    		Boolean isValid = DataTransferEncrypt.validKey();
        	if(!isValid) {
        		logger.error("您没有请求该接口的权限!");
                return CommonResponse.error("您没有请求该接口的权限!");
        	}
    	}
        return CommonResponse.success("查询成功！", extFieldsMode);
    }

    @PostMapping(value = "queryNumberBySql")
    @ResponseBody
    public CommonResponse<Integer> queryNumberBySql(@RequestBody Map<String, String> queryMap) {
        return commonQueryService.queryNumberBySql(queryMap);
    }

}

==> ejc-skeleton-3.0.1-20240201.035218-11-sources.jar: com/ejianc/framework/skeleton/commonQuery/controller/CommonQueryController.java <==
package com.ejianc.framework.skeleton.commonQuery.controller;

import com.alibaba.fastjson.JSONArray;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.commonQuery.service.ICommonQueryService;
import com.ejianc.framework.skeleton.fields.service.ICommenQueryFieldsService;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

/**
 * @author CJ
 * @Description:
 * @date 2020/7/29 17:21
 */
@RestController
@RequestMapping(value = "/commonQuery/")
public class CommonQueryController {

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private ICommenQueryFieldsService commenQueryFieldsService;
    @Autowired
    private ICommonQueryService commonQueryService;

    @Value("${extend.field.mode:false}")
    private Boolean extFieldsMode;

    @PostMapping(value = "queryBillInfoByProperty")
    @ResponseBody
    public CommonResponse<JSONArray> queryBillInfoByProperty(@RequestBody Map<String, String> queryMap) {
        if(StringUtils.isBlank(queryMap.get("databaseName"))) {
            logger.error("业务数据库名不能为空！");
            return CommonResponse.error("业务数据库名称不能为空");
        }
        if(StringUtils.isBlank(queryMap.get("tableName"))) {
            logger.error("业务表名不能为空！");
            return CommonResponse.error("业务表名称不能为空");
        }
        if(StringUtils.isBlank(queryMap.get("columns"))) {
            logger.error("查询字段不能为空！");
            return CommonResponse.error("查询字段不能为空");
        }
        if(StringUtils.isBlank(queryMap.get("parameter"))) {
            logger.error("查询条件不能为空！");
            return CommonResponse.error("查询条件不能为空");
        }
        JSONArray result = commenQueryFieldsService.queryBillInfoByProperty(queryMap.get("databaseName"), queryMap.get("tableName"), queryMap.get("columns"), queryMap.get("parameter"));

        return CommonResponse.success("查询成功！", result);
    }

    /** 查询当前工程是否开启扩展字段 */
    @PostMapping(value = "extFieldsModeOpen")
    @ResponseBody
    public CommonResponse<Boolean> extFieldsModeOpen(@RequestBody Map<String, String> queryMap) {
        return CommonResponse.success("查询成功！", extFieldsMode);
    }

    @PostMapping(value = "queryNumberBySql")
    @ResponseBody
    public CommonResponse<Integer> queryNumberBySql(@RequestBody Map<String, String> queryMap) {
        return commonQueryService.queryNumberBySql(queryMap);
    }

}
